.. _section_trouble:

===============
Troubleshooting
===============

Freezing / no output
~~~~~~~~~~~~~~~~~~~~
If the :ref:`CLI <section_command_line_interface>` freezes and you see a
blinking cursor for a very long time without any files being created
or changed in the output directory (*_dm* appended to the input data set):

1. Remove all files in the output directory, **except** for *drymass.cfg*.
2. Run the analysis again.


None of the above
~~~~~~~~~~~~~~~~~
Please `create an issue <https://github.com/RI-imaging/DryMass/issues>`_ on
GitHub with a screenshot (or copy-paste) of the error message.
